@@ -49,13 +49,13 @@ int main(int argc, char **argv) {
 
     KAboutData aboutData(QStringLiteral("bovo"), i18n("Bovo"),
             QStringLiteral(BOVO_VERSION_STRING), i18n("KDE Five in a Row Board Game"), KAboutLicense::GPL,
-            i18n("(c) 2002-2007, Aron Boström"), QString(), QStringLiteral("https://kde.org/applications/games/org.kde.bovo"));
+            i18n("(c) 2002-2007, Aron Boström"),
+            QString(),
+            QStringLiteral("https://apps.kde.org/bovo"));
     aboutData.addAuthor(i18n("Aron Boström"),i18n("Author"),
                         QStringLiteral("aron.bostrom@gmail.com"));
 
-    aboutData.setOrganizationDomain(QByteArray("kde.org"));
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("bovo")));
-    aboutData.setProductName(QByteArray("bovo"));
 
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
